@@ -1,10 +1,12 @@
 from .moran import (compute_mem, moran_randomization,
                     MoranRandomization)
 from .spin import spin_permutations, SpinPermutations
-
+from .variogram import SurrogateMaps, SampledSurrogateMaps
 
 __all__ = ['SpinPermutations',
            'MoranRandomization',
            'compute_mem',
            'moran_randomization',
-           'spin_permutations']
+           'spin_permutations',
+           'SurrogateMaps',
+           'SampledSurrogateMaps']
